import http from '@/api'
import type { BaseEntity } from '@/typings/api'
import type { FormConf } from '@/components/FormParser/type'
import type { ModelIcon } from '@/api/modules/flow/model'
import { type FlowGroup, getList as getGroups } from '@/api/modules/flow/group'
import { ProcessStatus } from '@/api/modules/flow/instance'
import type { FlowNode, OperationPermissions } from '@/api/modules/flow/flowDesign'

export interface FlowDefine extends BaseEntity {
  defineId: string
  key: string
  name: string
  version: number
  groupId: string
  icon: ModelIcon
  process: FlowNode
  form: FormConf
  deploymentId: string
  description: string
  suspend: number
}

export interface DefineGroup extends FlowGroup {
  defines: FlowDefine[]
}

export interface FormInfo {
  formName: string
  instanceId?: string
  taskId?: string
  flowDefine: FlowDefine
  status: ProcessStatus
  startUserId: string
  startTime: string
  endTime: string
  operations: OperationPermissions
}

export interface StartProcess {
  defineId: string
  instanceName: string
  businessKey: string
  values: Recordable
}

export const start = (startProcess: StartProcess) => {
  return http.post('/define/start', startProcess)
}

export const getStartForm = (defineId: string) => {
  return http.get<FormInfo>(`/define/startForm/${defineId}`)
}

export const getGroupList = async () => {
  const all = await Promise.all([getGroups(), getList()])
  if (all[0]) {
    const groups = all[0]
    const defines = all[1].success ? all[1].data : []
    return groups.map((group) => {
      return {
        ...group,
        defines: defines.filter((define) => define.groupId === group.id)
      }
    })
  }
}

export const getList = (query?: FlowDefine) => {
  return http.get<FlowDefine[]>('/define', query)
}

export const getDefine = (defineId: string) => {
  return http.get<FlowDefine>(`/define/${defineId}`)
}

export const suspend = (defineId: string) => {
  return http.put<FlowDefine>(`/define/suspend/${defineId}`)
}
