import { isEqual, isNumber } from 'lodash-es'
import type { FilterCondition, FilterGroup } from './type'

const useMatch = (formData: Recordable) => {
  /**
   * 匹配组
   * @param group
   */
  const matchesGroup = (group: FilterGroup): boolean => {
    const { conditions, groups, operator } = group
    if (operator === 'or') {
      const result = conditions.some((item) => matchesCondition(item))
      if (result) {
        return true
      } else if (groups) {
        return groups.some((item) => matchesGroup(item))
      } else {
        return false
      }
    } else {
      const result = conditions.every((item) => matchesCondition(item))
      if (result) {
        if (groups) {
          return groups.every((item) => matchesGroup(item))
        } else {
          return true
        }
      }
    }
    return false
  }

  /**
   * 匹配条件
   * @param condition
   */
  const matchesCondition = (condition: FilterCondition): boolean => {
    const { field, operator, value } = condition
    if (field) {
      const val = formData[field]
      switch (operator) {
        case 'eq':
          return isEqual(val, value)
        case 'ne':
          return !isEqual(val, value)
        case 'gt':
          if (isNumber(val)) {
            return val > value
          }
          return new Date(val).getTime() > new Date(value).getTime()
        case 'ge':
          if (isNumber(val)) {
            return val >= value
          }
          return new Date(val).getTime() >= new Date(value).getTime()
        case 'lt':
          if (isNumber(val)) {
            return val < value
          }
          return new Date(val).getTime() < new Date(value).getTime()
        case 'le':
          if (isNumber(val)) {
            return val <= value
          }
          return new Date(val).getTime() <= new Date(value).getTime()
        case 'nb':
          if (isNumber(val)) {
            return val < value[0] || val > value[1]
          }
          return (
            new Date(val).getTime() < new Date(value[0]).getTime() ||
            new Date(val).getTime() > new Date(value[1]).getTime()
          )
        case 'ul':
          return val === null || val === ''
        case 'nu':
          return val !== null && val !== ''
        case 'lk':
          return val.includes(value)
        case 'nl':
          return !val.includes(value)
        case 'in':
          return value.includes(val)
        case 'ni':
          return !value.includes(val)
        default:
          return false
      }
    }
    return false
  }

  return {
    matchesGroup,
    matchesCondition
  }
}

export default useMatch
