import { defineStore } from 'pinia'
import { getByUsername, type User } from '@/api/modules/system/user'

export interface UserCache {
  users: Recordable<User>
}

export const useUserCacheStore = defineStore({
  id: 'app-userCache',
  state: (): UserCache => ({
    users: {}
  }),
  getters: {
    usersGet: (state) => state.users
  },
  actions: {
    getUser(userId: string, force = false) {
      return new Promise<User>((resolve, reject) => {
        if (!force && this.users[userId]) {
          resolve(this.users[userId])
          return
        }
        getByUsername(userId).then((res) => {
          if (res.success) {
            this.users[userId] = res.data
            resolve(res.data)
          } else {
            reject(res.message)
          }
        })
      })
    },
    getUsers(userIds: string[], force = false) {
      return Promise.all(userIds.map((userId) => this.getUser(userId, force)))
    }
  }
})
