import { defineConfig, presetAttributify, presetMini, transformerDirectives, transformerVariantGroup } from 'unocss'
import presetIcons from '@unocss/preset-icons'
import presetRemToPx from '@unocss/preset-rem-to-px'

export default defineConfig({
  presets: [
    presetAttributify,
    presetIcons({
      scale: 1,
      warn: true,
      extraProperties: {
        'display': 'inline-block',
        'vertical-align': 'middle',
      }
    }),
    presetRemToPx({
      baseFontSize: 16
    }),
    presetMini()
  ],
  shortcuts: {
    'flex-col-center': 'flex-center flex-col',
    'flex-col': 'flex flex-col',
    'flex-items-center': 'flex items-center',
    'flex-center': 'flex-items-center justify-center',
    'flex-between': 'flex-items-center justify-between',
    'flex-space': 'flex-items-center flex-justify-between',
    'wh-full': 'w-full h-full'
  },
  transformers: [
    transformerVariantGroup(),
    transformerDirectives()
  ],
  safelist:[
    'i-ep:alarm-clock',
    'i-ep:calendar',
    'i-ep:list',
    'i-ph:briefcase',
    'i-ep:clock',
    'i-ep:cold-drink',
    'i-ep:fork-spoon',
    'i-ep:bicycle',
    'i-entypo:aircraft-take-off',
    'i-carbon:car',
    'i-ep:van',
    'i-ep:setting',
    'i-material-symbols:train',
    'i-bi:car-front',
    'i-whh-busalt',
    'i-ic:round-handshake',
    'i-icon-park-solid:robot-one',
    'i-ic:round-recycling',
    'i-carbon:fingerprint-recognition',
    'i-carbon:gas-station',
    'i-ant-design:apartment-outlined',
    'i-ep:bowl',
    'i-ic:sharp-recycling',
    'i-ic:sharp-local-florist',
    'i-ic:round-explore',
    'i-carbon:gas-station',
    'i-mdi:certificate',
    'i-clarity:rack-server-line',
    'i-bi:hdd',
    'i-bi:usb-drive',
    'i-bi:router',
    'i-ant-design:apartment-outlined',
    'i-ep:document',
    'i-ep:memo',
    'i-ep:printer',
    'i-ep:toilet-paper',
    'i-ep:video-camera',
    'i-ep:video-camera-filled',
    'i-bi:camera',
    'i-ep:stamp',
    'i-ep:hot-water',
    'i-ep:suitcase-line',
    'i-mdi-light:tag',
    'i-ep:postcard',
    'i-ic:baseline-mail-outline',
    'i-ic:outline-phone-android',
    'i-ep:phone-filled',
    'i-ic:outline-mic',
    'i-ic:baseline-directions-run',
    'i-ep:avatar',
    'i-mdi:account-wrench',
    'i-ic:baseline-group-add',
    'i-ic:baseline-group-remove',
    'i-ic:baseline-group-off',
    'i-ic:baseline-group',
    'i-ic:outline-family-restroom',
    'i-ic:sharp-usb',
    'i-ant-design:verified-outlined',
    'i-ic:sharp-wechat',
    'i-mingcute:qq-fill',
    'i-carbon:logo-youtube',
    'i-ion:logo-alipay',
    'i-ant-design:chrome-filled',
    'i-ion:battery-charging',
    'i-ep:map-location',
    'i-ep-chat-dot-round',
    'i-ep:office-building',
    'i-ep:school',
    'i-ep:switch',
    'i-ep:switch-button',
    'i-mdi:security',
    'i-uiw:file-excel',
    'i-uiw:file-jpg',
    'i-uiw:file-pdf',
    'i-bi:cake',
    'i-bi:calendar-date',
    'i-icon-park-outline:paper-money',
    'i-icon-park-outline:paper-money-two',
    'i-bi:cart2',
    'i-ep:guide',
    'i-carbon:logo-vue',
    'i-fluent:organization-12-regular',
    'i-fluent:organization-12-filled',
    'i-fluent:organization-horizontal-20-regular',
    'i-fluent:organization-horizontal-20-filled',
    'i-svg-spinners:12-dots-scale-rotate',
    'i-svg-spinners:blocks-shuffle-3',
    'i-svg-spinners:270-ring',
    'i-svg-spinners:clock',
    'i-svg-spinners:bars-scale'
  ],
  theme:{
    colors:{
      primary: 'var(--van-primary-color)',
      success: 'var(--van-success-color)',
      warning: 'var(--van-warning-color)',
      error: 'var(--van-danger-color)',
      background: 'var(--van-background)'
    }
  }
})
